HotKeysController class

Constructors

HotKeysController()

Properties

collectedModifiers List<TappyKeyboardKeyData>
final
hashCode int
The hash code for this object.
no setterinherited
isSequenceHotKeys bool
getter/setter pair
keyStream Stream<TappyKeyboardKeyData>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addHotKey(TappyKeyboardHotKey key) → void
Register a new hot-key combination
addKey(TappyKeyboardKeyData key) → void
Called by external code to inject a key event
clearModifierKeys() → void
dispose() → void
Clean up the stream when done
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited