TextInputFocusController class

Constructors

TextInputFocusController()

Properties

formState TappyFormState?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream Stream<bool>
no setter
textField EditableText?
getter/setter pair

Methods

dispose() → void
forceHideKeyboard() → void
hideKeyboard() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestKeyboardFocus() → void
requestKeyboardUnfocus() → void
showKeyboard() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited