TappyKeyAction enum

Inheritance
Available extensions

Values

exit → const TappyKeyAction
shift → const TappyKeyAction
tab → const TappyKeyAction
ctl → const TappyKeyAction
alt → const TappyKeyAction
space → const TappyKeyAction
backspace → const TappyKeyAction
enter → const TappyKeyAction
number → const TappyKeyAction
letter → const TappyKeyAction
symbol → const TappyKeyAction
func → const TappyKeyAction
left → const TappyKeyAction

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TappyKeyAction>
A constant List of the values in this enum, in order of their declaration.