TappyKeyboardController class
- Inheritance
-
- Object
- ChangeNotifier
- TappyKeyboardController
Constructors
Properties
- currentFormState → TappyFormState?
-
no setter
- currentTextField → EditableText?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- isSequenceHotKeys ↔ bool
-
getter/setter pair
-
keyboardToggleStream
→ Stream<
bool> -
no setter
- pane → TappyAlphanumericKeyboardPane
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shiftKeyEnabled → bool
-
no setter
Methods
-
addHotKey(
TappyKeyboardHotKey key) → void -
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
checkCombination(
TappyKeyboardKeyData key) → void -
clearModifierKeys(
) → void -
dispose(
) → void -
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
override
-
forceHideKeyboard(
) → void -
forceShowKeyboard(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
requestKeyboardFocus(
) → void -
requestKeyboardUnfocus(
) → void -
setKeyboardType(
TappyKeyboardType type) → void -
switchToLettersPane(
) → void - Switches to the letters pane
-
switchToSymbolsPane(
) → void - Switches to the symbols pane
-
togglePane(
) → void - Toggles between letters and symbols panes
-
toggleShift(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited