TappyKeyboardController class
- Inheritance
-
- Object
- ChangeNotifier
- TappyKeyboardController
Constructors
Properties
-
collectedModifiers
↔ List<
TappyKeyboardKeyData> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- inputController → TextInputFocusController
-
final
- pane ↔ TappyAlphanumericKeyboardPane
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shiftKeyEnabled → bool
-
no setter
Methods
-
addHotKey(
TappyKeyboardHotKey key) → void -
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
checkCombination(
TappyKeyboardKeyData key) → void -
dispose(
) → void -
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
override
-
forceHideKeyboard(
) → void -
forceShowKeyboard(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
switchPane(
) → void -
toggleShift(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited